@@ -263,8 +263,8 @@ void AuthWidgetPrivate::socketError(QAbstractSocket::SocketError socketError)
 {
     if (connection)
         connection->deleteLater();
-    qCDebug(KGAPIDebug) << QStringLiteral("Socket error when recieving response: %1").arg(socketError);
-    emitError(InvalidResponse, QStringLiteral("Error recieving response: %1").arg(socketError));
+    qCDebug(KGAPIDebug) << QStringLiteral("Socket error when receiving response: %1").arg(socketError);
+    emitError(InvalidResponse, tr("Error receiving response: %1").arg(socketError));
 }
 
 void AuthWidgetPrivate::socketReady()
@@ -284,11 +284,11 @@ void AuthWidgetPrivate::socketReady()
     const auto line = data.split(' ');
     if (line.size() != 3 || line.at(0) != QByteArray("GET") || !line.at(2).startsWith(QByteArray("HTTP/1.1"))) {
         qCDebug(KGAPIDebug) << QStringLiteral("Token response invalid");
-        emitError(InvalidResponse, QStringLiteral("Token response invalid"));
+        emitError(InvalidResponse, tr("Token response invalid"));
         return;
     }
 
-    //qCDebug(KGAPIRaw) << "Recieving data on socket: " << data;
+    //qCDebug(KGAPIRaw) << "Receiving data on socket: " << data;
     const QUrl url(QString::fromLatin1(line.at(1)));
     const QUrlQuery query(url.query());
     const QString code = query.queryItemValue(QStringLiteral("code"));
@@ -299,7 +299,7 @@ void AuthWidgetPrivate::socketReady()
             qCDebug(KGAPIDebug) << error;
         } else {
             qCDebug(KGAPIDebug) << QStringLiteral("Could not extract token from HTTP answer");
-            emitError(InvalidResponse, QStringLiteral("Could not extract token from HTTP answer"));
+            emitError(InvalidResponse, tr("Could not extract token from HTTP answer"));
         }
         return;
     }
